@@ -23,9 +23,6 @@ Session = saorm.scoped_session(
 
 sess = Session
 
-# we only need watch_session() until this bug fix gets released:
-# http://www.sqlalchemy.org/trac/ticket/2424#comment:5
-watch_session(sess)
 
 class Family(Base, ValidationMixin):
     __tablename__ = 'families'
@@ -143,6 +140,7 @@ class Order(Base, ValidationMixin):
     id = sa.Column(sa.Integer, primary_key=True)
     customer_id = sa.Column(sa.Integer, sa.ForeignKey(Customer.id), nullable=False)
     createdts = sa.Column(sa.DateTime, nullable=False, default=datetime.now, server_default=sasql.text('CURRENT_TIMESTAMP'))
+    note = sa.Column(sa.Text)
 
     val.validates_constraints()
 
